aboutsummaryrefslogtreecommitdiff
path: root/gdb/x86-64-tdep.h
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/x86-64-tdep.h')
-rw-r--r--gdb/x86-64-tdep.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/gdb/x86-64-tdep.h b/gdb/x86-64-tdep.h
index 76bb3d3..9163405 100644
--- a/gdb/x86-64-tdep.h
+++ b/gdb/x86-64-tdep.h
@@ -48,12 +48,13 @@ struct frame_info;
void x86_64_init_abi (struct gdbarch_info info, struct gdbarch *gdbarch);
/* Fill register REGNUM in GDB's register cache with the appropriate
floating-point or SSE register value from *FXSAVE. If REGNUM is
-1, do this for all registers. This function masks off any of the
reserved bits in *FXSAVE. */
-void x86_64_supply_fxsave (const char *fxsave, int regnum);
+extern void x86_64_supply_fxsave (struct regcache *regcache, int regnum,
+ const void *fxsave);
/* Fill register REGNUM (if it is a floating-point or SSE register) in
*FXSAVE with the value in GDB's register cache. If REGNUM is -1, do
@@ -48,12 +48,13 @@ struct frame_info;
void x86_64_init_abi (struct gdbarch_info info, struct gdbarch *gdbarch);
-/* Fill register REGNUM in GDB's register cache with the appropriate
+/* Fill register REGNUM in REGCACHE with the appropriate
floating-point or SSE register value from *FXSAVE. If REGNUM is